@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2009 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Archive.pm 1245 2007-10-02 14:09:25Z hikarin $
+# $Id: Archive.pm 1826 2009-04-08 15:23:25Z hikarin $
 #
 
 package Zeromin::Archive;
@@ -192,7 +192,7 @@ sub path {
 sub to_array_with_page {
     my ( $zArchive, $item_per_page, $offset ) = @_;
 
-    require Data::Page;
+    defined $Data::Page::VERSION or require Data::Page;
     my $entries = $zArchive->to_array();
     my $page = Data::Page->new( scalar @$entries, $item_per_page, $offset );
     return ( [ $page->splice($entries) ], $page );
